/*
 * Analogue TV Player plugin for VDR
 *
 * Copyright (C) 2003, 2005 Andreas Kool <akool@gmx.de>
 *
 * This code is distributed under the terms and conditions of the
 * GNU GENERAL PUBLIC LICENSE. See the file COPYING for details.
 *
 * $Id: i18n.c,v 1.58 2005/01/09 18:16:08 akool Exp $
 * Release: $Name:  $
 *
 */

#include "i18n.h"

const char *SoundDevices[] = SOUND_DEVICE_LABELS;

const char *audiomodes[] = {
    "Stereo",
    "Joint stereo",
    "Dual channel",
    "Mono"
};

const char *samplerates[] = {
    "22.05 KHz",
    "32 KHz",
    "44.1 KHz",
    "48 KHz",
    "96 KHz"
};

const char *analysismodes[] = {
    "Static",
    "Fast",
    "Accurate"
};

const char *loggers[] = {
    "none",
    "stdout",
    "syslog",
    "file"
};

const char *encoders[] = {
    "mp1e",
    "ffmpeg TS",
    "ffmpeg PES",
    "fame",
    "test",
    "lavrec",
    "mencoder",
    "PVR TS",
    "PVR PES",
    "nvrec TS",
    "nvrec PES"
};

const char *memcpys[] = {
    "Unknown",
    "glibc",
    "linux kernel",
    "MMX optimized",
    "MMXEXT optimized",
    "SSE optimized"
};

const char *imagesizes[] = { // Supported TMS320AV7110 PAL Video-Resolutions
    "352x288",
    "352x576",
    "480x576",
    "544x576",
    "704x576",
    "720x576"
};

const char *filters[] = {
    "1 YUV 4:2:0 fastest",
    "2 YUYV 4:2:2 fastest",
    "3 YUYV 4:2:2 v-decimation",
    "4 DONT USE", // "YUYV temporal interpolation" - is no longer available
    "5 YUYV 4:2:2 v-interpolation",
    "6 DONT USE", // "YUYV progressive" - Sorry, progressive mode out of order
    "7 DONT USE", // "YUYV progressive temporal" - Sorry, progressive mode out of order
    "8 YUV 4:2:0 v-decimation",
    "9 YUYV 4:2:2 h-decimation",
    "10 YUYV 4:2:2 4:1 decimation",
    "11 YVU 4:2:0 fastest"
};

const char *profiles[] = {
    "User defined",
    "fastest (weakly CPU)",
    "medium (like akool)",
    "best (strong CPU)",
    "low filesize",
    "PVR",
    "Automatic"
};

const char *tests[] = {
    "none",
    "audio fft, filter and mdct test",
    "video",
    "DONT USE",
    "video frame dropping test (20%)",
    "video effective bit rate",
    "deliberate sampling rate mismatch",
    "store raw audio data (driver interface test)", // capture raw audio as ./raw-audio
    "randomize video",
    "DONT USE",                                     // clock drift code
    "fixed video pattern, silent audio"
};

const char *grabsizes[] = { // Supported BTTV PAL Video-Resolutions
    "368x288",
    "368x576",
    "496x576",
    "560x576",
    "720x576",
    "736x576"
};

const char *epgsources[] = {
    "file",
    "pipe",
    "hoerzu2vdr"
};

const char *languages[] = {
    "none",
    "eng",
    "ger",
    "fra"
};

const char *gops[] = {
    "IBBPBBPBBPBBP",
    "I",
    "IPPPPP"
};

const char *dnr_modes[] = {
    "spatial and temporal",
    "temporal only",
    "spatial only",
    "none"
};

const char *closures[] = {
    "open",
    "closed"
};

const char *tvnorms[] = {
    "PAL",
    "NTSC",
    "SECAM"
};

const char *remuxes[] = {
    "none",
    "replex",
    "replex -f"
};

const char *digiboxmodes[] = {
    "none",
    "Sky",
    "Pace RC5",
    "Pace IRDA"
};

const char *bitratemodes[] = {
    "VBR",
    "CBR"
};

const char *aspects[] = {
    "1:1 square",
    "4:3",
    "16:9",
    "2.21:1",
};

const char *pulldowns[] = {
    "enabled",
    "disabled"
};

const tI18nPhrase AnalogtvPhrases[] = {
    {
        "Setup.analogTV$Watch analogue TV",    // English
        "Analoges Fernsehen",                  // Deutsch
        "Watch analogue TV", // TODO           // Slovenski
        "Watch analogue TV", // TODO           // Italiano
        "Watch analogue TV", // TODO           // Nederlands
        "Watch analogue TV", // TODO           // Portugus
        "Watch analogue TV", // TODO           // Franais
        "Watch analogue TV", // TODO           // Norsk
        "Watch analogue TV", // TODO           // Suomi
        "Watch analogue TV", // TODO           // Polski
        "Watch analogue TV", // TODO           // Espaol
        "Watch analogue TV", // TODO           // Ellinika
        "Watch analogue TV", // TODO           // Svenska
        "Watch analogue TV", // TODO           // Romaneste
        "Watch analogue TV", // TODO           // Magyar
        "Watch analogue TV"  // TODO           // Catal
    },
    {
        "Setup.analogTV$Setup AnalogTV",
        "AnalogTV Einstellungen",
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV", // TODO
        "Setup AnalogTV"  // TODO
    },
    {
        "Setup.analogTV$analogTV",
        "analogTV",
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV", // TODO
        "analogTV"  // TODO
    },
    {
        "Setup.analogTV$Picture Properties",
        "Bildeigenschaften",
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties", // TODO
        "Picture Properties"  // TODO
    },
    {
        "Setup.analogTV$Brightness",
        "Helligkeit",
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness", // TODO
        "Brightness"  // TODO
    },
    {
        "Setup.analogTV$Contrast",
        "Kontrast",
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast", // TODO
        "Contrast"  // TODO
    },
    {
        "Setup.analogTV$Colour",
        "Farbton",
        "Colour", // TODO
        "Colour", // TODO
        "Colour", // TODO
        "Colour", // TODO
        "Colour", // TODO
        "Colour", // TODO
        "Colour", // TODO
        "Colour", // TODO
        "Colour", // TODO
        "Colour", // TODO
        "Colour", // TODO
        "Colour", // TODO
        "Colour", // TODO
        "Colour"  // TODO
    },
    {
        "Setup.analogTV$Hue",
        "Sttigung",
        "Hue", // TODO
        "Hue", // TODO
        "Hue", // TODO
        "Hue", // TODO
        "Hue", // TODO
        "Hue", // TODO
        "Hue", // TODO
        "Hue", // TODO
        "Hue", // TODO
        "Hue", // TODO
        "Hue", // TODO
        "Hue", // TODO
        "Hue", // TODO
        "Hue"  // TODO
    },
    {
        "Setup.analogTV$Finetune",
        "Feintuning",
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune", // TODO
        "Finetune"  // TODO
    },
    {
        "Setup.analogTV$EPG",
        "EPG",
        "EPG", // TODO
        "EPG", // TODO
        "EPG", // TODO
        "EPG", // TODO
        "EPG", // TODO
        "EPG", // TODO
        "EPG", // TODO
        "EPG", // TODO
        "EPG", // TODO
        "EPG", // TODO
        "EPG", // TODO
        "EPG", // TODO
        "EPG", // TODO
        "EPG"  // TODO
    },
    {
        "Setup.analogTV$Load EPG now",
        "EPG jetzt laden",
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now", // TODO
        "Load EPG now"  // TODO
    },
    {
        "Setup.analogTV$EPG from",
        "EPG aus",
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from", // TODO
        "EPG from"  // TODO
    },
    {
        "Setup.analogTV$External program",
        "Externes Programm",
        "External program", // TODO
        "External program", // TODO
        "External program", // TODO
        "External program", // TODO
        "External program", // TODO
        "External program", // TODO
        "External program", // TODO
        "External program", // TODO
        "External program", // TODO
        "External program", // TODO
        "External program", // TODO
        "External program", // TODO
        "External program", // TODO
        "External program"  // TODO
    },
    {
        "Setup.analogTV$EPG provider",
        "EPG Anbieter",
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider", // TODO
        "EPG provider"  // TODO
    },
    {
        "Setup.analogTV$Autoupdate (hours)",
        "Automatisch laden (Stunden)",
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)", // TODO
        "Autoupdate (hours)"  // TODO
    },
    {
        "Setup.analogTV$Theme language",
        "Thema in Sprache",
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language", // TODO
        "Theme language"  // TODO
    },
    {
        "Setup.analogTV$MPEG Encoder",
        "MPEG Encoder",
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder", // TODO
        "MPEG Encoder"  // TODO
    },
    {
        "Setup.analogTV$Restart encoder",
        "Neustart",
        "Restart", // TODO
        "Restart", // TODO
        "Restart", // TODO
        "Restart", // TODO
        "Restart", // TODO
        "Restart", // TODO
        "Restart", // TODO
        "Restart", // TODO
        "Restart", // TODO
        "Restart", // TODO
        "Restart", // TODO
        "Restart", // TODO
        "Restart", // TODO
        "Restart"  // TODO
    },
    {
        "Setup.analogTV$Stop encoder",
        "Encoder stoppen",
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder", // TODO
        "Stop encoder"  // TODO
    },
    {
        "Setup.analogTV$Encoder",
        "Encoder",
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder", // TODO
        "Encoder"  // TODO
    },
    {
        "Setup.analogTV$Video bit rate (Mbit/s)/100000",
        "Video Bitrate (Mbit/s)/100000",
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000", // TODO
        "Video bit rate (Mbit/s)/100000"  // TODO
    },
    {
        "Setup.analogTV$Audio bit rate (kbit/s)",
        "Audio Bitrate (kbit/s)",
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)", // TODO
        "Audio bit rate (kbit/s)"  // TODO
    },
    {
        "Setup.analogTV$Image size",
        "Bildgre",
        "Image size", // TODO
        "Image size", // TODO
        "Image size", // TODO
        "Image size", // TODO
        "Image size", // TODO
        "Image size", // TODO
        "Image size", // TODO
        "Image size", // TODO
        "Image size", // TODO
        "Image size", // TODO
        "Image size", // TODO
        "Image size", // TODO
        "Image size", // TODO
        "Image size"  // TODO
    },
    {
        "Setup.analogTV$Clipping",
        "Rnder abschneiden",
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping", // TODO
        "Clipping"  // TODO
    },
    {
        "Setup.analogTV$GOP sequence",
        "GOP Sequenz",
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence", // TODO
        "GOP sequence"  // TODO
    },
    {
        "Setup.analogTV$Filter",
        "Filter",
        "Filter", // TODO
        "Filter", // TODO
        "Filter", // TODO
        "Filter", // TODO
        "Filter", // TODO
        "Filter", // TODO
        "Filter", // TODO
        "Filter", // TODO
        "Filter", // TODO
        "Filter", // TODO
        "Filter", // TODO
        "Filter", // TODO
        "Filter", // TODO
        "Filter"  // TODO
    },
    {
        "Setup.analogTV$Motion compensation min",
        "Bewegungskompensation min",
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min", // TODO
        "Motion compensation min"  // TODO
    },
    {
        "Setup.analogTV$Motion compensation max",
        "Bewegungskompensation max",
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max", // TODO
        "Motion compensation max"  // TODO
    },
    {
        "Setup.analogTV$Deinterlacing",
        "Zeilensprung entfernen",
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing", // TODO
        "Deinterlacing"  // TODO
    },
    {
        "Setup.analogTV$Profile",
        "Profil",
        "Profile", // TODO
        "Profile", // TODO
        "Profile", // TODO
        "Profile", // TODO
        "Profile", // TODO
        "Profile", // TODO
        "Profile", // TODO
        "Profile", // TODO
        "Profile", // TODO
        "Profile", // TODO
        "Profile", // TODO
        "Profile", // TODO
        "Profile", // TODO
        "Profile"  // TODO
    },
    {
        "Setup.analogTV$MPEG",
        "MPEG",
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG", // TODO
        "MPEG"  // TODO
    },
    {
        "Setup.analogTV$Test",
        "Test",
        "Test", // TODO
        "Test", // TODO
        "Test", // TODO
        "Test", // TODO
        "Test", // TODO
        "Test", // TODO
        "Test", // TODO
        "Test", // TODO
        "Test", // TODO
        "Test", // TODO
        "Test", // TODO
        "Test", // TODO
        "Test", // TODO
        "Test"  // TODO
    },
    {
        "Setup.analogTV$Audiodevice",
        "Audioeinheit",
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice", // TODO
        "Audiodevice"  // TODO
    },
    {
        "Setup.analogTV$PCM device",
        "Audioeinheit",
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device", // TODO
        "PCM device"  // TODO
    },
    {
        "Setup.analogTV$OSS Mixer device",
        "OSS Mixereinheit",
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device", // TODO
        "OSS Mixer device"  // TODO
    },
    {
        "Setup.analogTV$OSS Mixer input",
        "OSS Mixereingang",
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input", // TODO
        "OSS Mixer input"  // TODO
    },
    {
        "Setup.analogTV$Audio volume",
        "Lautstrke",
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume", // TODO
        "Audio volume"  // TODO
    },
    {
        "Setup.analogTV$Use PVR350 TV-out",
        "PVR350 TV-Ausgang verwenden",
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out", // TODO
        "Use PVR350 TV-out"  // TODO
    },
    {
        "Setup.analogTV$GOP size",
        "GOP Gre",
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size", // TODO
        "GOP size"  // TODO
    },
    {
        "Setup.analogTV$B frames",
        "B frames",
        "B frames", // TODO
        "B frames", // TODO
        "B frames", // TODO
        "B frames", // TODO
        "B frames", // TODO
        "B frames", // TODO
        "B frames", // TODO
        "B frames", // TODO
        "B frames", // TODO
        "B frames", // TODO
        "B frames", // TODO
        "B frames", // TODO
        "B frames", // TODO
        "B frames"  // TODO
    },
    {
        "Setup.analogTV$GOP",
        "GOP",
        "GOP", // TODO
        "GOP", // TODO
        "GOP", // TODO
        "GOP", // TODO
        "GOP", // TODO
        "GOP", // TODO
        "GOP", // TODO
        "GOP", // TODO
        "GOP", // TODO
        "GOP", // TODO
        "GOP", // TODO
        "GOP", // TODO
        "GOP", // TODO
        "GOP"  // TODO
    },
    {
        "Setup.analogTV$Noise removal filter",
        "Strungsbeseitigungsfilter",
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter", // TODO
        "Noise removal filter"  // TODO
    },
    {
        "Setup.analogTV$Spatial",
        "Rumlich",
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial", // TODO
        "Spatial"  // TODO
    },
    {
        "Setup.analogTV$Temporal",
        "Zeitlich",
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal", // TODO
        "Temporal"  // TODO
    },
    {
        "Setup.analogTV$Type",
        "Type",
        "Type", // TODO
        "Type", // TODO
        "Type", // TODO
        "Type", // TODO
        "Type", // TODO
        "Type", // TODO
        "Type", // TODO
        "Type", // TODO
        "Type", // TODO
        "Type", // TODO
        "Type", // TODO
        "Type", // TODO
        "Type", // TODO
        "Type"  // TODO
    },
    {
        "Setup.analogTV$Bitrate mode",
        "Bitrate Modus",
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode", // TODO
        "Bitrate mode"  // TODO
    },
    {
        "Setup.analogTV$Aspect",
        "Aspekt",
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect", // TODO
        "Aspect"  // TODO
    },
    {
        "Setup.analogTV$3:2 pulldown",
        "3:2 pulldown",
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown", // TODO
        "3:2 pulldown"  // TODO
    },
    {
        "Setup.analogTV$On the fly remux",
        "On the fly remux",
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux", // TODO
        "On the fly remux"  // TODO
    },
    {
        "Setup.analogTV$Hacks",
        "Hacks",
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks", // TODO
        "Hacks"  // TODO
    },
    {
        "Setup.analogTV$sync hack",
        "sync hack",
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack", // TODO
        "sync hack"  // TODO
    },
    {
        "Setup.analogTV$wining hack",
        "wining hack",
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack", // TODO
        "wining hack"  // TODO
    },
    {
        "Setup.analogTV$picture properties hack",
        "picture properties hack",
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack", // TODO
        "picture properties hack"  // TODO
    },
    {
        "Setup.analogTV$stuttering hack",
        "stuttering hack",
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack", // TODO
        "stuttering hack"  // TODO
    },
    {
        "Setup.analogTV$Audio mode",
        "Audiomodus",
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode", // TODO
        "Audio mode"  // TODO
    },
    {
        "Setup.analogTV$Audio sample rate",
        "Sample rate",
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate", // TODO
        "Audio sample rate"  // TODO
    },
    {
        "Setup.analogTV$Psychoacoustic analysis",
        "Psychoakustische Analyse",
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis", // TODO
        "Psychoacoustic analysis"  // TODO
    },
    {
        "Setup.analogTV$Various",
        "Diverses",
        "Various", // TODO
        "Various", // TODO
        "Various", // TODO
        "Various", // TODO
        "Various", // TODO
        "Various", // TODO
        "Various", // TODO
        "Various", // TODO
        "Various", // TODO
        "Various", // TODO
        "Various", // TODO
        "Various", // TODO
        "Various", // TODO
        "Various"  // TODO
    },
    {
        "Setup.analogTV$Debug level",
        "Debug level",
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level", // TODO
        "Debug level"  // TODO
    },
    {
        "Setup.analogTV$Debug output",
        "Debug Ausgabe",
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output", // TODO
        "Debug output"  // TODO
    },
    {
        "Setup.analogTV$Report",
        "Protokoll",
        "Report", // TODO
        "Report", // TODO
        "Report", // TODO
        "Report", // TODO
        "Report", // TODO
        "Report", // TODO
        "Report", // TODO
        "Report", // TODO
        "Report", // TODO
        "Report", // TODO
        "Report", // TODO
        "Report", // TODO
        "Report", // TODO
        "Report"  // TODO
    },
    {
        "Setup.analogTV$Hide Mainmenu Entry",
        "Verstecke Hauptmeneintrag",
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry", // TODO
        "Hide Mainmenu Entry"  // TODO
    },
    {
        "Setup.analogTV$Encoder always running",
        "Encoder luft immer",
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running", // TODO
        "Encoder always running"  // TODO
    },
    {
        "Setup.analogTV$Link to encoder",
        "Verbindung zum Encoder",
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder", // TODO
        "Link to encoder"  // TODO
    },
    {
        "Setup.analogTV$read()",
        "read()",
        "read()", // TODO
        "read()", // TODO
        "read()", // TODO
        "read()", // TODO
        "read()", // TODO
        "read()", // TODO
        "read()", // TODO
        "read()", // TODO
        "read()", // TODO
        "read()", // TODO
        "read()", // TODO
        "read()", // TODO
        "read()", // TODO
        "read()"  // TODO
    },
    {
        "Setup.analogTV$select()",
        "select()",
        "select()", // TODO
        "select()", // TODO
        "select()", // TODO
        "select()", // TODO
        "select()", // TODO
        "select()", // TODO
        "select()", // TODO
        "select()", // TODO
        "select()", // TODO
        "select()", // TODO
        "select()", // TODO
        "select()", // TODO
        "select()", // TODO
        "select()"  // TODO
    },
    {
        "Setup.analogTV$Reset",
        "Zurcksetzen",
        "Reset", // TODO
        "Reset", // TODO
        "Reset", // TODO
        "Reset", // TODO
        "Reset", // TODO
        "Reset", // TODO
        "Reset", // TODO
        "Reset", // TODO
        "Reset", // TODO
        "Reset", // TODO
        "Reset", // TODO
        "Reset", // TODO
        "Reset", // TODO
        "Reset"  // TODO
    },
    {
        "Setup.analogTV$Internals",
        "Internes",
        "Internals", // TODO
        "Internals", // TODO
        "Internals", // TODO
        "Internals", // TODO
        "Internals", // TODO
        "Internals", // TODO
        "Internals", // TODO
        "Internals", // TODO
        "Internals", // TODO
        "Internals", // TODO
        "Internals", // TODO
        "Internals", // TODO
        "Internals", // TODO
        "Internals"  // TODO
    },
    {
        "Setup.analogTV$[Video source]",
        "[Videoquelle]",
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]", // TODO
        "[Video source]"  // TODO
    },
    {
        "Setup.analogTV$Unknown",
        "Unbekannt",
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown", // TODO
        "Unknown"  // TODO
    },
    {
        "Setup.analogTV$[Encoder running]",
        "[luft der Encoder]",
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]", // TODO
        "[Encoder running]"  // TODO
    },
    {
        "Setup.analogTV$[Encoder needed]",
        "[wird Encoder bentigt]",
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]", // TODO
        "[Encoder needed]"  // TODO
    },
    {
        "Setup.analogTV$[Frequency]",
        "[Frequenz]",
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]", // TODO
        "[Frequency]"  // TODO
    },
    {
        "Setup.analogTV$[Brightness]",
        "[Helligkeit]",
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]", // TODO
        "[Brightness]"  // TODO
    },
    {
        "Setup.analogTV$[Contrast]",
        "[Kontrast]",
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]", // TODO
        "[Contrast]"  // TODO
    },
    {
        "Setup.analogTV$[Colour]",
        "[Farbe]",
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]", // TODO
        "[Colour]"  // TODO
    },
    {
        "Setup.analogTV$[Hue]",
        "[Sttigung]",
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]", // TODO
        "[Hue]"  // TODO
    },
    {
        "Setup.analogTV$[CPU]",
        "[CPU]",
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]", // TODO
        "[CPU]"  // TODO
    },
    {
        "Setup.analogTV$[Speed (MHz)]",
        "[Geschwindigkeit (MHz)]",
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]", // TODO
        "[Speed (MHz)]"  // TODO
    },
    {
        "Setup.analogTV$[memcpy() method]",
        "[memcpy() Methode]",
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]", // TODO
        "[memcpy() method]"  // TODO
    },
    {
        "Setup.analogTV$[Grab size]",
        "[Grabbing Gre]",
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]", // TODO
        "[Grab size]"  // TODO
    },
    {
        "Setup.analogTV$Cannot change encoder now!",
        "Encoder kann momentan nicht gewechselt werden!",
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!", // TODO
        "Cannot change encoder now!"  // TODO
    },
    {
        "Setup.analogTV$Cannot change image size now!",
        "Bildgre kann momentan nicht gendert werden!",
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!", // TODO
        "Cannot change image size now!"  // TODO
    },
    {
        "Setup.analogTV$Loading of EPG failed",
        "Laden des EPG fehlgeschlagen",
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed", // TODO
        "Loading of EPG failed"  // TODO
    },
    {
        "Setup.analogTV$Really stop encoder?",
        "Wirklich Encoder stoppen?",
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?", // TODO
        "Really stop encoder?"  // TODO
    },
    {
        "Setup.analogTV$Cannot stop encoder now!",
        "Encoder kann jetzt nicht gestoppt werden!",
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!", // TODO
        "Cannot stop encoder now!"  // TODO
    },
    {
        "Setup.analogTV$Encoder does not run!",
        "Encoder luft nicht!",
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!", // TODO
        "Encoder does not run!"  // TODO
    },
    {
        "Setup.analogTV$Really reset analogTV plugin?",
        "Wirklich analogTV plugin zurcksetzen?",
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?", // TODO
        "Really reset analogTV plugin?"  // TODO
    },
    {
        "Setup.analogTV$No",
        "Nein",
        "No", // TODO
        "No", // TODO
        "No", // TODO
        "No", // TODO
        "No", // TODO
        "No", // TODO
        "No", // TODO
        "No", // TODO
        "No", // TODO
        "No", // TODO
        "No", // TODO
        "No", // TODO
        "No", // TODO
        "No"  // TODO
    },
    {
        "Setup.analogTV$Yes",
        "Ja",
        "Yes", // TODO
        "Yes", // TODO
        "Yes", // TODO
        "Yes", // TODO
        "Yes", // TODO
        "Yes", // TODO
        "Yes", // TODO
        "Yes", // TODO
        "Yes", // TODO
        "Yes", // TODO
        "Yes", // TODO
        "Yes", // TODO
        "Yes", // TODO
        "Yes"  // TODO
    },
    {
        "Setup.analogTV$DigiBox control",
        "DigiBox Kontrolle",
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
        "DigiBox control",   // TODO
    },
    {
        "Setup.analogTV$Digibox Mode",
        "Digibox Modus",
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
        "Digibox Mode",      // TODO
    },
    {
	"Setup.analogTV$Redremote Device",
	"Redremote Gert",
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
	"Redremote Device",  // TODO
    },
    {
	"Setup.analogTV$Backup Hack",
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
	"Backup Hack",       // TODO
    },
    {
	"Setup.analogTV$Backup Interval",
	"Backup Abstand",
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
	"Backup Interval",   // TODO
    },
    {
	"Setup.analogTV$Fast Channel Change",
	"Schneller Kanalwechsel", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
	"Fast channel change", //TODO
    },
    { NULL }
};

#if 0 // Template
    {
        "Setup.analogTV$",
        "",
        "", // TODO
        "", // TODO
        "", // TODO
        "", // TODO
        "", // TODO
        "", // TODO
        "", // TODO
        "", // TODO
        "", // TODO
        "", // TODO
        "", // TODO
        "", // TODO
        "", // TODO
        ""  // TODO
    },
#endif
